@@ -16,6 +16,7 @@ from model_clone.utils import (
     get_fields_and_unique_fields_from_cls,
     get_unique_default,
     get_unique_value,
+    get_value,
     transaction_autocommit,
 )
 
@@ -90,12 +91,14 @@ class CloneMixin(object):
     _clone_excluded_m2o_or_o2m_fields = []  # type: List[str]
     _clone_excluded_o2o_fields = []  # type: List[str]
 
+    DUPLICATE_SUFFIX = "copy"  # type: str
+    USE_DUPLICATE_SUFFIX_FOR_NON_UNIQUE_FIELDS = False  # type: bool
     UNIQUE_DUPLICATE_SUFFIX = "copy"  # type: str
     USE_UNIQUE_DUPLICATE_SUFFIX = True  # type: bool
     MAX_UNIQUE_DUPLICATE_QUERY_ATTEMPTS = 100  # type: int
 
     @classmethod
-    def check(cls, **kwargs):
+    def check(cls, **kwargs):  # pragma: no cover
         errors = super(CloneMixin, cls).check(**kwargs)
 
         if cls.USE_UNIQUE_DUPLICATE_SUFFIX and not cls.UNIQUE_DUPLICATE_SUFFIX:
@@ -113,6 +116,21 @@ class CloneMixin(object):
                 )
             )
 
+        if cls.USE_DUPLICATE_SUFFIX_FOR_NON_UNIQUE_FIELDS and not cls.DUPLICATE_SUFFIX:
+            errors.append(
+                Error(
+                    "UNIQUE_DUPLICATE_SUFFIX is required.",
+                    hint=(
+                        "Please provide DUPLICATE_SUFFIX"
+                        + " for {} or set USE_DUPLICATE_SUFFIX_FOR_NON_UNIQUE_FIELDS=False".format(
+                            cls.__name__
+                        )
+                    ),
+                    obj=cls,
+                    id="{}.E001".format(ModelCloneConfig.name),
+                )
+            )
+
         if all([cls._clone_fields, cls._clone_excluded_fields]):
             errors.append(
                 Error(
@@ -309,9 +327,19 @@ class CloneMixin(object):
             "MAX_UNIQUE_DUPLICATE_QUERY_ATTEMPTS",
             CloneMixin.MAX_UNIQUE_DUPLICATE_QUERY_ATTEMPTS,
         )
+        duplicate_suffix = getattr(
+            cls,
+            "DUPLICATE_SUFFIX",
+            CloneMixin.DUPLICATE_SUFFIX,
+        )
+        use_duplicate_suffix_for_non_unique_fields = getattr(
+            cls,
+            "USE_DUPLICATE_SUFFIX_FOR_NON_UNIQUE_FIELDS",
+            CloneMixin.USE_DUPLICATE_SUFFIX_FOR_NON_UNIQUE_FIELDS,
+        )
 
         fields, unique_fields = get_fields_and_unique_fields_from_cls(
-            cls=cls,
+            model=cls,
             force=force,
             clone_fields=clone_fields,
             clone_excluded_fields=clone_excluded_fields,
@@ -381,6 +409,24 @@ class CloneMixin(object):
                         )
                         sub_instance.save(using=using)
                         value = sub_instance.pk
+            elif all(
+                [
+                    use_duplicate_suffix_for_non_unique_fields,
+                    f.concrete,
+                    f.editable,
+                    f.name not in unique_fields,
+                ]
+            ):
+                if (
+                    isinstance(f, (models.CharField, models.TextField))
+                    and not f.choices
+                ):
+                    value = get_value(
+                        value=value,
+                        transform=(slugify if isinstance(f, SlugField) else str),
+                        suffix=duplicate_suffix,
+                        max_length=f.max_length,
+                    )
 
             setattr(new_instance, f.attname, value)
 
